<html>
  <body>
    <h1 style="font-size: 16px">{{ site }}</h1>
    <p>Please click the following link to complete your user activation. {{ activation_key }}</p>
    <p>This activation will will expire in {{ expiration_days }}</p>
  </body>
</html>
